@@ -1,13 +1,11 @@
 package ezvcard;
 
-import java.io.File;
-import java.io.IOException;
 import java.io.InputStream;
 import java.io.Reader;
 import java.net.URL;
+import java.nio.file.Path;
 import java.util.Arrays;
 import java.util.Collection;
-import java.util.Properties;
 
 import org.w3c.dom.Document;
 
@@ -32,10 +30,9 @@ import ezvcard.io.text.VCardWriter;
 import ezvcard.io.xml.XCardDocument;
 import ezvcard.io.xml.XCardReader;
 import ezvcard.io.xml.XCardWriter;
-import ezvcard.util.IOUtils;
 
 /*
- Copyright (c) 2012-2020, Michael Angstadt
+ Copyright (c) 2012-2023, Michael Angstadt
  All rights reserved.
 
  Redistribution and use in source and binary forms, with or without
@@ -102,40 +99,22 @@ public final class Ezvcard {
 	/**
 	 * The version of the library.
 	 */
-	public static final String VERSION;
+	public static final String VERSION = "0.12.1";
 
 	/**
 	 * The Maven group ID.
 	 */
-	public static final String GROUP_ID;
+	public static final String GROUP_ID = "com.googlecode.ez-vcard";
 
 	/**
 	 * The Maven artifact ID.
 	 */
-	public static final String ARTIFACT_ID;
+	public static final String ARTIFACT_ID = "ez-vcard";
 
 	/**
 	 * The project webpage.
 	 */
-	public static final String URL;
-
-	static {
-		InputStream in = null;
-		Properties props = new Properties();
-		try {
-			in = Ezvcard.class.getResourceAsStream("ez-vcard.properties");
-			props.load(in);
-		} catch (IOException e) {
-			throw new RuntimeException(e);
-		} finally {
-			IOUtils.closeQuietly(in);
-		}
-
-		VERSION = props.getProperty("version");
-		GROUP_ID = props.getProperty("groupId");
-		ARTIFACT_ID = props.getProperty("artifactId");
-		URL = props.getProperty("url");
-	}
+	public static final String URL = "https://github.com/mangstadt/ez-vcard";
 
 	/**
 	 * <p>
@@ -169,8 +148,8 @@ public final class Ezvcard {
 	 * @see <a href="http://tools.ietf.org/html/rfc2426">RFC 2426 (3.0)</a>
 	 * @see <a href="http://tools.ietf.org/html/rfc6350">RFC 6350 (4.0)</a>
 	 */
-	public static ChainingTextParser<ChainingTextParser<?>> parse(File file) {
-		return new ChainingTextParser<ChainingTextParser<?>>(file);
+	public static ChainingTextParser<ChainingTextParser<?>> parse(Path file) {
+		return new ChainingTextParser<>(file);
 	}
 
 	/**
@@ -188,7 +167,7 @@ public final class Ezvcard {
 	 * @see <a href="http://tools.ietf.org/html/rfc6350">RFC 6350 (4.0)</a>
 	 */
 	public static ChainingTextParser<ChainingTextParser<?>> parse(InputStream in) {
-		return new ChainingTextParser<ChainingTextParser<?>>(in);
+		return new ChainingTextParser<>(in);
 	}
 
 	/**
@@ -206,7 +185,7 @@ public final class Ezvcard {
 	 * @see <a href="http://tools.ietf.org/html/rfc6350">RFC 6350 (4.0)</a>
 	 */
 	public static ChainingTextParser<ChainingTextParser<?>> parse(Reader reader) {
-		return new ChainingTextParser<ChainingTextParser<?>>(reader);
+		return new ChainingTextParser<>(reader);
 	}
 
 	/**
@@ -241,8 +220,8 @@ public final class Ezvcard {
 	 * @see XCardReader
 	 * @see <a href="http://tools.ietf.org/html/rfc6351">RFC 6351</a>
 	 */
-	public static ChainingXmlParser<ChainingXmlParser<?>> parseXml(File file) {
-		return new ChainingXmlParser<ChainingXmlParser<?>>(file);
+	public static ChainingXmlParser<ChainingXmlParser<?>> parseXml(Path file) {
+		return new ChainingXmlParser<>(file);
 	}
 
 	/**
@@ -260,7 +239,7 @@ public final class Ezvcard {
 	 * @see <a href="http://tools.ietf.org/html/rfc6351">RFC 6351</a>
 	 */
 	public static ChainingXmlParser<ChainingXmlParser<?>> parseXml(InputStream in) {
-		return new ChainingXmlParser<ChainingXmlParser<?>>(in);
+		return new ChainingXmlParser<>(in);
 	}
 
 	/**
@@ -286,7 +265,7 @@ public final class Ezvcard {
 	 * @see <a href="http://tools.ietf.org/html/rfc6351">RFC 6351</a>
 	 */
 	public static ChainingXmlParser<ChainingXmlParser<?>> parseXml(Reader reader) {
-		return new ChainingXmlParser<ChainingXmlParser<?>>(reader);
+		return new ChainingXmlParser<>(reader);
 	}
 
 	/**
@@ -335,8 +314,8 @@ public final class Ezvcard {
 	 * @see HCardParser
 	 * @see <a href="http://microformats.org/wiki/hcard">hCard 1.0</a>
 	 */
-	public static ChainingHtmlParser<ChainingHtmlParser<?>> parseHtml(File file) {
-		return new ChainingHtmlParser<ChainingHtmlParser<?>>(file);
+	public static ChainingHtmlParser<ChainingHtmlParser<?>> parseHtml(Path file) {
+		return new ChainingHtmlParser<>(file);
 	}
 
 	/**
@@ -352,7 +331,7 @@ public final class Ezvcard {
 	 * @see <a href="http://microformats.org/wiki/hcard">hCard 1.0</a>
 	 */
 	public static ChainingHtmlParser<ChainingHtmlParser<?>> parseHtml(InputStream in) {
-		return new ChainingHtmlParser<ChainingHtmlParser<?>>(in);
+		return new ChainingHtmlParser<>(in);
 	}
 
 	/**
@@ -368,7 +347,7 @@ public final class Ezvcard {
 	 * @see <a href="http://microformats.org/wiki/hcard">hCard 1.0</a>
 	 */
 	public static ChainingHtmlParser<ChainingHtmlParser<?>> parseHtml(Reader reader) {
-		return new ChainingHtmlParser<ChainingHtmlParser<?>>(reader);
+		return new ChainingHtmlParser<>(reader);
 	}
 
 	/**
@@ -384,7 +363,7 @@ public final class Ezvcard {
 	 * @see <a href="http://microformats.org/wiki/hcard">hCard 1.0</a>
 	 */
 	public static ChainingHtmlParser<ChainingHtmlParser<?>> parseHtml(URL url) {
-		return new ChainingHtmlParser<ChainingHtmlParser<?>>(url);
+		return new ChainingHtmlParser<>(url);
 	}
 
 	/**
@@ -415,8 +394,8 @@ public final class Ezvcard {
 	 * @see JCardReader
 	 * @see <a href="http://tools.ietf.org/html/rfc7095">RFC 7095</a>
 	 */
-	public static ChainingJsonParser<ChainingJsonParser<?>> parseJson(File file) {
-		return new ChainingJsonParser<ChainingJsonParser<?>>(file);
+	public static ChainingJsonParser<ChainingJsonParser<?>> parseJson(Path file) {
+		return new ChainingJsonParser<>(file);
 	}
 
 	/**
@@ -432,7 +411,7 @@ public final class Ezvcard {
 	 * @see <a href="http://tools.ietf.org/html/rfc7095">RFC 7095</a>
 	 */
 	public static ChainingJsonParser<ChainingJsonParser<?>> parseJson(InputStream in) {
-		return new ChainingJsonParser<ChainingJsonParser<?>>(in);
+		return new ChainingJsonParser<>(in);
 	}
 
 	/**
@@ -448,7 +427,7 @@ public final class Ezvcard {
 	 * @see <a href="http://tools.ietf.org/html/rfc7095">RFC 7095</a>
 	 */
 	public static ChainingJsonParser<ChainingJsonParser<?>> parseJson(Reader reader) {
-		return new ChainingJsonParser<ChainingJsonParser<?>>(reader);
+		return new ChainingJsonParser<>(reader);
 	}
 
 	/**
