@@ -1,15 +1,13 @@
 package ezvcard.io.text;
 
-import java.io.BufferedReader;
-import java.io.File;
-import java.io.FileNotFoundException;
-import java.io.FileReader;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.Reader;
 import java.io.StringReader;
 import java.nio.charset.Charset;
+import java.nio.file.Files;
+import java.nio.file.Path;
 import java.util.ArrayList;
 import java.util.List;
 
@@ -40,7 +38,7 @@ import ezvcard.util.IOUtils;
 import ezvcard.util.StringUtils;
 
 /*
- Copyright (c) 2012-2020, Michael Angstadt
+ Copyright (c) 2012-2023, Michael Angstadt
  All rights reserved.
 
  Redistribution and use in source and binary forms, with or without
@@ -77,16 +75,12 @@ import ezvcard.util.StringUtils;
  * </p>
  * 
  * <pre class="brush:java">
- * File file = new File("vcards.vcf");
- * VCardReader reader = null;
- * try {
- *   reader = new VCardReader(file);
+ * Path file = Paths.get("vcards.vcf");
+ * try (VCardReader reader = new VCardReader(file)) {
  *   VCard vcard;
  *   while ((vcard = reader.readNext()) != null) {
  *     //...
  *   }
- * } finally {
- *   if (reader != null) reader.close();
  * }
  * </pre>
  * @author Michael Angstadt
@@ -137,9 +131,9 @@ public class VCardReader extends StreamReader {
 	/**
 	 * Creates a new vCard reader.
 	 * @param file the file to read from
-	 * @throws FileNotFoundException if the file doesn't exist
+	 * @throws IOException if there is a problem opening the file
 	 */
-	public VCardReader(File file) throws FileNotFoundException {
+	public VCardReader(Path file) throws IOException {
 		this(file, VCardVersion.V2_1);
 	}
 
@@ -148,10 +142,10 @@ public class VCardReader extends StreamReader {
 	 * @param file the file to read from
 	 * @param defaultVersion the version to assume the vCard is in until a
 	 * VERSION property is encountered (defaults to 2.1)
-	 * @throws FileNotFoundException if the file doesn't exist
+	 * @throws IOException if there is a problem opening the file
 	 */
-	public VCardReader(File file, VCardVersion defaultVersion) throws FileNotFoundException {
-		this(new BufferedReader(new FileReader(file)), defaultVersion);
+	public VCardReader(Path file, VCardVersion defaultVersion) throws IOException {
+		this(Files.newBufferedReader(file), defaultVersion);
 	}
 
 	/**
@@ -392,7 +386,7 @@ public class VCardReader extends StreamReader {
 				if (nestedVCard != null) {
 					exception.injectVCard(nestedVCard);
 				}
-			} catch (IOException e) {
+			} catch (IOException ignore) {
 				//shouldn't be thrown because we're reading from a string
 			} finally {
 				warnings.addAll(agentReader.getWarnings());
@@ -541,14 +535,14 @@ public class VCardReader extends StreamReader {
 	 * Keeps track of the hierarchy of nested vCards.
 	 */
 	private static class VCardStack {
-		private final List<Item> stack = new ArrayList<Item>();
+		private final List<Item> stack = new ArrayList<>();
 
 		/**
 		 * Adds a vCard to the stack.
 		 * @param vcard the vcard to add
 		 */
 		public void push(VCard vcard) {
-			stack.add(new Item(vcard, new ArrayList<Label>()));
+			stack.add(new Item(vcard, new ArrayList<>()));
 		}
 
 		/**
