@@ -1,15 +1,19 @@
 package ezvcard.util;
 
 import java.text.DecimalFormat;
+import java.text.DecimalFormatSymbols;
 import java.text.NumberFormat;
+import java.time.DateTimeException;
+import java.time.ZoneOffset;
 import java.util.Arrays;
+import java.util.Locale;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
 import ezvcard.Messages;
 
 /*
- Copyright (c) 2012-2020, Michael Angstadt
+ Copyright (c) 2012-2023, Michael Angstadt
  All rights reserved.
 
  Redistribution and use in source and binary forms, with or without
@@ -69,8 +73,8 @@ public final class PartialDate {
 	private static final int HOUR = 3;
 	private static final int MINUTE = 4;
 	private static final int SECOND = 5;
-	private static final int TIMEZONE_HOUR = 6;
-	private static final int TIMEZONE_MINUTE = 7;
+	private static final int OFFSET_HOUR = 6;
+	private static final int OFFSET_MINUTE = 7;
 
 	//@formatter:off
 	private static final Format dateFormats[] = new Format[] {
@@ -83,29 +87,26 @@ public final class PartialDate {
 	};
 	//@formatter:on
 
-	private static final String timezoneRegex = "(([-+]\\d{1,2}):?(\\d{2})?)?";
+	private static final String offsetRegex = "(([-+]\\d{1,2}):?(\\d{2})?)?";
 
 	//@formatter:off
 	private static final Format timeFormats[] = new Format[] {
-		new Format("(\\d{2})" + timezoneRegex, HOUR, null, TIMEZONE_HOUR, TIMEZONE_MINUTE),
-		new Format("(\\d{2}):?(\\d{2})" + timezoneRegex, HOUR, MINUTE, null, TIMEZONE_HOUR, TIMEZONE_MINUTE),
-		new Format("(\\d{2}):?(\\d{2}):?(\\d{2})" + timezoneRegex, HOUR, MINUTE, SECOND, null, TIMEZONE_HOUR, TIMEZONE_MINUTE),
-		new Format("-(\\d{2}):?(\\d{2})" + timezoneRegex, MINUTE, SECOND, null, TIMEZONE_HOUR, TIMEZONE_MINUTE),
-		new Format("-(\\d{2})" + timezoneRegex, MINUTE, null, TIMEZONE_HOUR, TIMEZONE_MINUTE),
-		new Format("--(\\d{2})" + timezoneRegex, SECOND, null, TIMEZONE_HOUR, TIMEZONE_MINUTE)
+		new Format("(\\d{2})" + offsetRegex, HOUR, null, OFFSET_HOUR, OFFSET_MINUTE),
+		new Format("(\\d{2}):?(\\d{2})" + offsetRegex, HOUR, MINUTE, null, OFFSET_HOUR, OFFSET_MINUTE),
+		new Format("(\\d{2}):?(\\d{2}):?(\\d{2})" + offsetRegex, HOUR, MINUTE, SECOND, null, OFFSET_HOUR, OFFSET_MINUTE),
+		new Format("-(\\d{2}):?(\\d{2})" + offsetRegex, MINUTE, SECOND, null, OFFSET_HOUR, OFFSET_MINUTE),
+		new Format("-(\\d{2})" + offsetRegex, MINUTE, null, OFFSET_HOUR, OFFSET_MINUTE),
+		new Format("--(\\d{2})" + offsetRegex, SECOND, null, OFFSET_HOUR, OFFSET_MINUTE)
 	};
 	//@formatter:on
 
 	private final Integer[] components;
-	private final UtcOffset offset;
 
 	/**
 	 * @param components the date/time components array
-	 * @param offset the UTC offset or null if not set
 	 */
-	private PartialDate(Integer[] components, UtcOffset offset) {
+	private PartialDate(Integer[] components) {
 		this.components = components;
-		this.offset = offset;
 	}
 
 	/**
@@ -279,16 +280,18 @@ public final class PartialDate {
 	 * Gets the UTC offset.
 	 * @return the UTC offset or null if not set
 	 */
-	public UtcOffset getUtcOffset() {
-		return offset;
-	}
+	public ZoneOffset getUtcOffset() {
+		Integer hour = components[OFFSET_HOUR];
+		if (hour == null) {
+			return null;
+		}
 
-	/**
-	 * Determines if this date has a timezone component.
-	 * @return true if the component is set, false if not
-	 */
-	private boolean hasUtcOffset() {
-		return offset != null;
+		Integer minute = components[OFFSET_MINUTE];
+		if (minute == null) {
+			return ZoneOffset.ofHours(hour);
+		}
+
+		return ZoneOffset.ofHoursMinutes(hour, minute);
 	}
 
 	/**
@@ -317,8 +320,14 @@ public final class PartialDate {
 	 * {@link #builder()} method
 	 */
 	public String toISO8601(boolean extended) {
-		StringBuilder sb = new StringBuilder();
-		NumberFormat nf = new DecimalFormat("00");
+		/*
+		 * Micro-optimization: The max length a timestamp string can possibly be
+		 * is 25. Example: 2012-07-01T14:21:10-05:00
+		 */
+		final int maxPossibleLength = 25;
+
+		StringBuilder sb = new StringBuilder(maxPossibleLength);
+		NumberFormat nf = new DecimalFormat("00", DecimalFormatSymbols.getInstance(Locale.ROOT));
 
 		String yearStr = hasYear() ? getYear().toString() : null;
 		String monthStr = hasMonth() ? nf.format(getMonth()) : null;
@@ -336,6 +345,7 @@ public final class PartialDate {
 		} else if (!hasYear() && hasMonth() && hasDate()) {
 			sb.append("--").append(monthStr).append(dash).append(dateStr);
 		} else if (hasYear() && !hasMonth() && hasDate()) {
+			//this is checked for in the builder and should never be thrown here
 			throw new IllegalStateException(Messages.INSTANCE.getExceptionMessage(38));
 		} else if (hasYear() && hasMonth() && hasDate()) {
 			sb.append(yearStr).append(dash).append(monthStr).append(dash).append(dateStr);
@@ -360,13 +370,20 @@ public final class PartialDate {
 			} else if (!hasHour() && hasMinute() && hasSecond()) {
 				sb.append("-").append(minuteStr).append(dash).append(secondStr);
 			} else if (hasHour() && !hasMinute() && hasSecond()) {
+				//this is checked for in the builder and should never be thrown here
 				throw new IllegalStateException(Messages.INSTANCE.getExceptionMessage(39));
 			} else if (hasHour() && hasMinute() && hasSecond()) {
 				sb.append(hourStr).append(dash).append(minuteStr).append(dash).append(secondStr);
 			}
 
-			if (hasUtcOffset()) {
-				sb.append(offset.toString(extended));
+			Integer offsetHour = components[OFFSET_HOUR];
+			if (offsetHour != null) {
+				Integer offsetMinute = components[OFFSET_MINUTE];
+				String offsetHourStr = nf.format(Math.abs(offsetHour));
+				String offsetMinuteStr = nf.format(Math.abs(offsetMinute));
+
+				sb.append((offsetHour < 0 || offsetMinute < 0) ? '-' : '+');
+				sb.append(offsetHourStr).append(dash).append(offsetMinuteStr);
 			}
 		}
 
@@ -378,7 +395,6 @@ public final class PartialDate {
 		final int prime = 31;
 		int result = 1;
 		result = prime * result + Arrays.hashCode(components);
-		result = prime * result + ((offset == null) ? 0 : offset.hashCode());
 		return result;
 	}
 
@@ -389,9 +405,6 @@ public final class PartialDate {
 		if (getClass() != obj.getClass()) return false;
 		PartialDate other = (PartialDate) obj;
 		if (!Arrays.equals(components, other.components)) return false;
-		if (offset == null) {
-			if (other.offset != null) return false;
-		} else if (!offset.equals(other.offset)) return false;
 		return true;
 	}
 
@@ -411,7 +424,7 @@ public final class PartialDate {
 		 * @param regex the regular expression that describes the format
 		 * @param componentIndexes the indexes of the
 		 * {@link PartialDate#components} array to assign the value of each
-		 * regex group to, or -1 to ignore the group
+		 * regex group to, or null to ignore the group
 		 */
 		public Format(String regex, Integer... componentIndexes) {
 			this.regex = Pattern.compile('^' + regex + '$');
@@ -422,7 +435,9 @@ public final class PartialDate {
 		 * Tries to parse a given string.
 		 * @param builder the object to assign the parsed data to
 		 * @param value the string to parse
-		 * @return true if the string was successfully parsed, false if not
+		 * @return true if the string matches this format's regex, false if not
+		 * @throws IllegalArgumentException if a value in the date string is
+		 * invalid (e.g. "13" for the month)
 		 */
 		public boolean parse(Builder builder, String value) {
 			Matcher m = regex.matcher(value);
@@ -430,8 +445,18 @@ public final class PartialDate {
 				return false;
 			}
 
+			/*
+			 * All this complicated handling of the offset is due to:
+			 * 
+			 * The hour portion can be zero, and zero can't be negative (e.g.
+			 * "-00:30").
+			 * 
+			 * There is no positive or negative sign next to the minute portion
+			 * in the string.
+			 */
 			boolean offsetPositive = false;
 			Integer offsetHour = null, offsetMinute = null;
+
 			for (int i = 0; i < componentIndexes.length; i++) {
 				Integer index = componentIndexes[i];
 				if (index == null) {
@@ -447,16 +472,24 @@ public final class PartialDate {
 					}
 
 					int component = Integer.parseInt(groupStr);
-					if (index == TIMEZONE_HOUR) {
+					if (index == YEAR) {
+						builder.year(component);
+					} else if (index == MONTH) {
+						builder.month(component);
+					} else if (index == DATE) {
+						builder.date(component);
+					} else if (index == HOUR) {
+						builder.hour(component);
+					} else if (index == MINUTE) {
+						builder.minute(component);
+					} else if (index == SECOND) {
+						builder.second(component);
+					} else if (index == OFFSET_HOUR) {
 						offsetHour = component;
 						offsetPositive = startsWithPlus;
-						continue;
-					}
-					if (index == TIMEZONE_MINUTE) {
+					} else if (index == OFFSET_MINUTE) {
 						offsetMinute = component;
-						continue;
 					}
-					builder.components[index] = component;
 				}
 			}
 
@@ -464,8 +497,19 @@ public final class PartialDate {
 				if (offsetMinute == null) {
 					offsetMinute = 0;
 				}
-				builder.offset = new UtcOffset(offsetPositive, offsetHour, offsetMinute);
+				if (!offsetPositive) {
+					offsetMinute *= -1;
+				}
+
+				ZoneOffset offset;
+				try {
+					offset = ZoneOffset.ofHoursMinutes(offsetHour, offsetMinute);
+				} catch (DateTimeException e) {
+					throw new IllegalArgumentException(e);
+				}
+				builder.offset(offset);
 			}
+
 			return true;
 		}
 	}
@@ -476,10 +520,9 @@ public final class PartialDate {
 	 */
 	public static class Builder {
 		private final Integer[] components;
-		private UtcOffset offset;
 
 		public Builder() {
-			components = new Integer[6];
+			components = new Integer[8];
 		}
 
 		/**
@@ -487,7 +530,6 @@ public final class PartialDate {
 		 */
 		public Builder(PartialDate original) {
 			components = original.components.clone();
-			offset = original.offset;
 		}
 
 		/**
@@ -582,11 +624,17 @@ public final class PartialDate {
 
 		/**
 		 * Sets the timezone offset.
-		 * @param offset the timezone offset
+		 * @param offset the offset
 		 * @return this
 		 */
-		public Builder offset(UtcOffset offset) {
-			this.offset = offset;
+		public Builder offset(ZoneOffset offset) {
+			if (offset == null) {
+				components[OFFSET_HOUR] = null;
+				components[OFFSET_MINUTE] = null;
+			} else {
+				components[OFFSET_HOUR] = offset.getTotalSeconds() / 3600;
+				components[OFFSET_MINUTE] = (offset.getTotalSeconds() % 3600) / 60;
+			}
 			return this;
 		}
 
@@ -605,7 +653,7 @@ public final class PartialDate {
 				throw Messages.INSTANCE.getIllegalArgumentException(39);
 			}
 
-			return new PartialDate(components, offset);
+			return new PartialDate(components);
 		}
 	}
 }
