@@ -30,7 +30,7 @@ import ezvcard.util.HtmlUtils;
 import ezvcard.util.XmlUtils;
 
 /*
- Copyright (c) 2012-2020, Michael Angstadt
+ Copyright (c) 2012-2023, Michael Angstadt
  All rights reserved.
 
  Redistribution and use in source and binary forms, with or without
@@ -68,7 +68,7 @@ public class Sensei<T extends VCardProperty> {
 	 * @return the new instance
 	 */
 	public static <T extends VCardProperty> Sensei<T> create(VCardPropertyScribe<T> scribe) {
-		return new Sensei<T>(scribe);
+		return new Sensei<>(scribe);
 	}
 
 	/**
@@ -464,11 +464,7 @@ public class Sensei<T extends VCardProperty> {
 		 * objects will be compared with the {@code equals()} method.
 		 */
 		public void run(final T expected) {
-			run(new Check<T>() {
-				public void check(T actual) {
-					assertEquals(expected, actual);
-				}
-			}, -1);
+			run(actual -> assertEquals(expected, actual), -1);
 		}
 
 		/**
