@@ -7,11 +7,12 @@ import static org.custommonkey.xmlunit.XMLAssert.assertXMLEqual;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
 
-import java.io.File;
 import java.io.IOException;
 import java.io.InputStreamReader;
+import java.nio.charset.StandardCharsets;
+import java.nio.file.Path;
+import java.time.ZoneOffset;
 
-import ezvcard.parameter.Encoding;
 import org.custommonkey.xmlunit.XMLUnit;
 import org.junit.BeforeClass;
 import org.junit.Rule;
@@ -39,6 +40,7 @@ import ezvcard.io.text.WriteContext;
 import ezvcard.io.xml.XCardDocument.XCardDocumentStreamWriter;
 import ezvcard.parameter.AddressType;
 import ezvcard.parameter.EmailType;
+import ezvcard.parameter.Encoding;
 import ezvcard.parameter.ImageType;
 import ezvcard.parameter.Pid;
 import ezvcard.parameter.TelephoneType;
@@ -63,14 +65,13 @@ import ezvcard.property.Url;
 import ezvcard.property.VCardProperty;
 import ezvcard.property.Xml;
 import ezvcard.property.asserter.VCardAsserter;
-import ezvcard.util.PartialDate;
 import ezvcard.util.Gobble;
+import ezvcard.util.PartialDate;
 import ezvcard.util.TelUri;
-import ezvcard.util.UtcOffset;
 import ezvcard.util.XmlUtils;
 
 /*
- Copyright (c) 2012-2020, Michael Angstadt
+ Copyright (c) 2012-2023, Michael Angstadt
  All rights reserved.
 
  Redistribution and use in source and binary forms, with or without
@@ -672,10 +673,10 @@ public class XCardDocumentTest {
 		XCardDocument xcard = new XCardDocument();
 		xcard.addVCard(vcard);
 
-		File file = tempFolder.newFile();
+		Path file = tempFolder.newFile().toPath();
 		xcard.write(file);
 
-		String xml = new Gobble(file).asString("UTF-8");
+		String xml = new Gobble(file).asString(StandardCharsets.UTF_8);
 		assertTrue(xml.matches("(?i)<\\?xml.*?encoding=\"utf-8\".*?\\?>.*"));
 		assertTrue(xml.matches(".*?<note><text>\u019dote</text></note>.*"));
 	}
@@ -792,7 +793,7 @@ public class XCardDocumentTest {
 		Birthday bday = new Birthday(PartialDate.builder().month(2).date(3).build());
 		vcard.setBirthday(bday);
 
-		Anniversary anniversary = new Anniversary(PartialDate.builder().year(2009).month(8).date(8).hour(14).minute(30).offset(new UtcOffset(false, -5, 0)).build());
+		Anniversary anniversary = new Anniversary(PartialDate.builder().year(2009).month(8).date(8).hour(14).minute(30).offset(ZoneOffset.ofHours(-5)).build());
 		vcard.setAnniversary(anniversary);
 
 		vcard.setGender(Gender.male());
@@ -876,7 +877,7 @@ public class XCardDocumentTest {
 				.date(8)
 				.hour(14)
 				.minute(30)
-				.offset(new UtcOffset(false, -5, 0))
+				.offset(ZoneOffset.ofHours(-5))
 				.build()
 			)
 		.noMore();
