@@ -11,9 +11,12 @@ import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
-import java.io.File;
 import java.io.IOException;
 import java.io.Writer;
+import java.nio.charset.StandardCharsets;
+import java.nio.file.Files;
+import java.nio.file.Path;
+import java.time.ZoneOffset;
 import java.util.Iterator;
 
 import javax.xml.transform.TransformerException;
@@ -55,12 +58,10 @@ import ezvcard.property.Xml;
 import ezvcard.property.asserter.VCardAsserter;
 import ezvcard.util.PartialDate;
 import ezvcard.util.TelUri;
-import ezvcard.util.UtcOffset;
-import ezvcard.util.Utf8Writer;
 import ezvcard.util.XmlUtils;
 
 /*
- Copyright (c) 2012-2020, Michael Angstadt
+ Copyright (c) 2012-2023, Michael Angstadt
  All rights reserved.
 
  Redistribution and use in source and binary forms, with or without
@@ -736,10 +737,10 @@ public class XCardReaderTest {
 			"</vcard>" +
 		"</vcards>";
 
-		File file = tempFolder.newFile();
-		Writer writer = new Utf8Writer(file);
-		writer.write(xml);
-		writer.close();
+		Path file = tempFolder.newFile().toPath();
+		try (Writer writer = Files.newBufferedWriter(file, StandardCharsets.UTF_8)) {
+			writer.write(xml);
+		}
 
 		XCardReader reader = new XCardReader(file);
 		VCardAsserter asserter = new VCardAsserter(reader);
@@ -788,7 +789,7 @@ public class XCardReaderTest {
 				.date(8)
 				.hour(14)
 				.minute(30)
-				.offset(new UtcOffset(false, -5, 0))
+				.offset(ZoneOffset.ofHours(-5))
 				.build()
 			)
 		.noMore();
